@@ -27,6 +27,7 @@ from httpx import ReadTimeout, RequestError, InvalidURL
 from wapitiCore.main.log import log_red, log_orange, log_verbose, logging
 from wapitiCore.attack.attack import Attack, Parameter
 from wapitiCore.model import PayloadInfo
+from wapitiCore.net.web import http_repr
 from wapitiCore.parsers.ini_payload_parser import IniPayloadReader, replace_tags
 from wapitiCore.language.vulnerability import Messages
 from wapitiCore.definitions.file import PathTraversalFinding
@@ -134,11 +135,11 @@ class ModuleFile(Attack):
             self.network_errors += 1
             # Can't check out, avoid false negative
             return False
-        else:
-            if pattern in response.content:
-                # Store false positive information in order to prevent doing unnecessary requests
-                self.known_false_positives[request.path_id].add(pattern)
-                return True
+
+        if pattern in response.content:
+            # Store false positive information in order to prevent doing unnecessary requests
+            self.known_false_positives[request.path_id].add(pattern)
+            return True
 
         return False
 
@@ -172,7 +173,7 @@ class ModuleFile(Attack):
                 log_orange("---")
                 log_orange(Messages.MSG_TIMEOUT, page)
                 log_orange(Messages.MSG_EVIL_REQUEST)
-                log_orange(mutated_request.http_repr())
+                log_orange(http_repr(mutated_request))
                 log_orange("---")
 
                 if parameter.is_qs_injection:
@@ -181,7 +182,6 @@ class ModuleFile(Attack):
                     anom_msg = Messages.MSG_PARAM_TIMEOUT.format(parameter.display_name)
 
                 await self.add_medium(
-                    request_id=request.path_id,
                     finding_class=ResourceConsumptionFinding,
                     request=mutated_request,
                     info=anom_msg,
@@ -192,7 +192,7 @@ class ModuleFile(Attack):
                 self.network_errors += 1
                 continue
             except InvalidURL:
-                logging.warning(f"Invalid URL: {mutated_request.url} potentially vulnerable to open redirect")
+                logging.warning("Invalid URL: %s potentially vulnerable to open redirect", mutated_request.url)
                 continue
             else:
                 file_warning = None
@@ -240,7 +240,6 @@ class ModuleFile(Attack):
                             vuln_message += " (" + constraint_message + ")"
 
                     await self.add_critical(
-                        request_id=request.path_id,
                         finding_class=PathTraversalFinding,
                         request=mutated_request,
                         info=vuln_message,
@@ -260,7 +259,7 @@ class ModuleFile(Attack):
                         log_red(constraint_message)
 
                     log_red(Messages.MSG_EVIL_REQUEST)
-                    log_red(mutated_request.http_repr())
+                    log_red(http_repr(mutated_request))
                     log_red("---")
 
                     if inclusion_succeed:
@@ -276,7 +275,6 @@ class ModuleFile(Attack):
                         anom_msg = Messages.MSG_PARAM_500.format(parameter.display_name)
 
                     await self.add_high(
-                        request_id=request.path_id,
                         finding_class=InternalErrorFinding,
                         request=mutated_request,
                         info=anom_msg,
@@ -287,5 +285,5 @@ class ModuleFile(Attack):
                     log_orange("---")
                     log_orange(Messages.MSG_500, page)
                     log_orange(Messages.MSG_EVIL_REQUEST)
-                    log_orange(mutated_request.http_repr())
+                    log_orange(http_repr(mutated_request))
                     log_orange("---")
