@@ -29,6 +29,7 @@ from wapitiCore.language.vulnerability import Messages
 from wapitiCore.definitions.ssrf import SsrfFinding
 from wapitiCore.model import PayloadInfo, str_to_payloadinfo
 from wapitiCore.net import Request, Response
+from wapitiCore.net.web import http_repr
 
 SSRF_PAYLOAD = "{external_endpoint}ssrf/{random_id}/{path_id}/{hex_param}/"
 
@@ -81,7 +82,7 @@ class ModuleSsrf(Attack):
 
     async def finish(self):
         endpoint_url = f"{self.internal_endpoint}get_ssrf.php?session_id={self._session_id}"
-        logging.info(f"[*] Asking endpoint URL {endpoint_url} for results, please wait...")
+        logging.info("[*] Asking endpoint URL %s for results, please wait...", endpoint_url)
         await sleep(2)
         # When attacks are down we ask the endpoint for receive requests
         endpoint_request = Request(endpoint_url)
@@ -89,7 +90,7 @@ class ModuleSsrf(Attack):
             response = await self.crawler.async_send(endpoint_request)
         except RequestError:
             self.network_errors += 1
-            logging.error(f"[!] Unable to request endpoint URL '{self.internal_endpoint}'")
+            logging.error("[!] Unable to request endpoint URL '%s'", self.internal_endpoint)
         else:
             data = response.json
             if isinstance(data, dict):
@@ -133,7 +134,6 @@ class ModuleSsrf(Attack):
                             ))
 
                             await self.add_critical(
-                                request_id=original_request.path_id,
                                 finding_class=SsrfFinding,
                                 request=mutated_request,
                                 info=vuln_message,
@@ -150,5 +150,5 @@ class ModuleSsrf(Attack):
                                 parameter
                             )
                             log_red(Messages.MSG_EVIL_REQUEST)
-                            log_red(mutated_request.http_repr())
+                            log_red(http_repr(mutated_request))
                             log_red("---")
