@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 # This file is part of the Wapiti project (https://wapiti-scanner.github.io)
-# Copyright (C) 2023 Nicolas SURRIBAS
+# Copyright (C) 2023-2025 Nicolas SURRIBAS
 # Copyright (C) 2023-2024 Cyberwatch
 #
 # This program is free software; you can redistribute it and/or modify
@@ -19,7 +19,6 @@
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 import asyncio
 import os
-import shutil
 import sys
 from collections import deque
 from dataclasses import replace
@@ -29,6 +28,7 @@ from typing import List, Deque
 from urllib.parse import urlparse
 
 import browser_cookie3
+from playwright.async_api import async_playwright, Error as PlaywrightError
 
 from wapitiCore import WAPITI_VERSION
 from wapitiCore.attack.active_scanner import ActiveScanner
@@ -42,7 +42,7 @@ from wapitiCore.net.intercepting_explorer import InterceptingExplorer
 from wapitiCore.net.scope import Scope
 from wapitiCore.net.sql_persister import SqlPersister
 from wapitiCore.report import get_report_generator_instance
-from wapitiCore.main.log import logging
+from wapitiCore.main.log import logging, configure, log_green, log_red, log_blue
 
 SCAN_FORCE_VALUES = {
     "paranoid": 1,
@@ -120,8 +120,6 @@ class Wapiti:
 
     def refresh_logging(self):
         message_format = "{message}"
-        if self.color_enabled:
-            message_format = "<lvl>" + message_format + "</lvl>"
 
         verbosity_levels = {
             0: "BLUE",
@@ -139,7 +137,7 @@ class Wapiti:
         ]
         if self._logfile:
             handlers.append({"sink": self._logfile, "level": "DEBUG"})
-        logging.configure(handlers=handlers)
+        configure(handlers=handlers)
 
     def set_logfile(self, filename: str):
         self._logfile = filename
@@ -156,15 +154,14 @@ class Wapiti:
         self.report_gen = get_report_generator_instance(self.report_generator_type.lower())
 
         self.report_gen.set_report_info(
-            self.base_request.url,
-            self.target_scope.name,
-            gmtime(),
-            f"Wapiti {WAPITI_VERSION}",
-            self._auth_state,
-            await self.persister.get_necessary_paths() if self.detailed_report_level == 1 \
-            else await self.persister.get_all_paths() if self.detailed_report_level == 2 else None,
-            await self.count_resources(),
-            self.detailed_report_level
+            target=self.base_request.url,
+            scope=self.target_scope.name,
+            date=gmtime(),
+            version=f"Wapiti {WAPITI_VERSION}",
+            auth=self._auth_state,
+            crawled_pages=await self.persister.get_crawled_paths() if self.detailed_report_level == 2 else [],
+            crawled_pages_nbr=await self.count_resources(),
+            detailed_report_level=self.detailed_report_level
         )
 
         for vul in vulnerabilities:
@@ -205,11 +202,11 @@ class Wapiti:
         await self.persister.set_root_url(self.base_request.url)
 
     async def save_scan_state(self):
-        logging.log("GREEN", "[*] Saving scan state, please wait...")
+        log_blue("[*] Saving scan state, please wait...")
         # Not yet scanned URLs are all saved in one single time (bulk insert + final commit)
         await self.persister.set_to_browse(self._start_urls)
 
-        logging.info(f"This scan has been saved in the file {self.persister.output_file}")
+        log_green("This scan has been saved in the file {0}", self.persister.output_file)
         # if stopped and self._start_urls:
         #     print(_("The scan will be resumed next time unless you pass the --skip-crawl option."))
 
@@ -320,11 +317,11 @@ class Wapiti:
                 )
 
         print('')
-        logging.log("GREEN", "[*] Generating report...")
+        log_blue("[*] Generating report...")
         self.report_gen.generate_report(self.output_file)
-        logging.success(f"A report has been generated in the file {self.output_file}")
+        log_green(f"A report has been generated in the file {self.output_file}")
         if self.report_generator_type == "html":
-            logging.success(f"Open {self.report_gen.final_path} with a browser to see this report.")
+            log_blue(f"Open {self.report_gen.final_path} with a browser to see this report.")
 
         await self.persister.close()
 
@@ -357,12 +354,25 @@ class Wapiti:
                     "--proxy", f"The proxy protocol '{parts.scheme}' is not supported by mitmproxy"
                 )
 
-    def set_headless(self, headless_mode: str):
+    async def set_headless(self, headless_mode: str):
         """Set the headless mode used for browsing"""
-        if headless_mode != "no" and not shutil.which("geckodriver"):
-            logging.error("Headless mode won't be activated because geckodriver is missing on the system")
-        else:
-            self._headless_mode = headless_mode
+        if headless_mode != "no":
+            async with async_playwright() as p:
+                try:
+                    if not os.path.exists(p.firefox.executable_path):
+                        log_red(
+                            "Firefox is not installed. "
+                            "Please run `playwright install firefox`"
+                        )
+                        self._headless_mode = "no"
+                    else:
+                        self._headless_mode = headless_mode
+                except PlaywrightError:
+                    log_red(
+                        "Could not find browser installation. "
+                        "Please run `playwright install --with-deps firefox`"
+                    )
+                    self._headless_mode = "no"
 
     @property
     def headless_mode(self) -> str:
